const editor = document.querySelector('.article-editor');
const options = {
  placeholder: '请输入正文',
};
const quill = new Quill(editor, options);

/**
 * 注册编辑器分割线
 */
const BlockEmbed = Quill.import('blots/block/embed');

class DividerBlot extends BlockEmbed { }

// 分割线
DividerBlot.blotName = 'divider';
DividerBlot.tagName = 'hr';

Quill.register(DividerBlot);

class HhImageBlot extends BlockEmbed {
  static create(value) {
    let node = super.create(value);
    let wrap = document.createElement('div');
    node.setAttribute('src', value);
    wrap.appendChild(node)
    return wrap;
  }

  static value(domNode) {
    return domNode.getAttribute('src');
  }
}

HhImageBlot.blotName = 'hhImage';
HhImageBlot.tagName = 'IMG';

Quill.register(HhImageBlot);

/**
 * title相关事件
 */
const titleInput = document.querySelector('.title-textarea');

titleInput.addEventListener('input', (e) => {
  callWebviewMethod('jkttTitleChange', e.target.value);
})

titleInput.addEventListener('focus', () => {
  callWebviewMethod('jkttTitleFocus', null);
})

titleInput.addEventListener('blur', () => {
  callWebviewMethod('jkttTitleBlur', null);
})

/**
 * 编辑器change事件
 */
quill.on('text-change', (delta, oldDelta, source) => {
  let html = editor.children[0].innerHTML;
  const text = quill.getText();

  if (html === '<p><br></p>') html = '';

  const dataMap = {
    text,
    html,
    history: quill.history.stack,
    format: quill.getFormat()
  }

  callWebviewMethod('jkttContentChange', JSON.stringify(dataMap));
});

/**
 * 编辑器光标改变事件
 */
quill.on('selection-change', (range, oldRange, source) => {
  if (range) {
    callWebviewMethod('jkttEditorFocus', quill.getFormat())
  } else {
    callWebviewMethod('jkttEditorBlur')
  }
});

// quill.root.addEventListener('focus', () => {
//   callWebviewMethod('jkttEditorFocus', quill.getFormat())
// });

// quill.root.addEventListener('blur', () => {
//   callWebviewMethod('jkttEditorBlur')
// });

// respond to clicks inside the editor
quill.root.addEventListener('click', this.handleClick, false);

// 编辑器格式化内容
window.formatText = (name, value) => {
  quill.format(name, value);
}

// 插入图片
window.insertImage = (urls) => {
  // 获取光标所在位置
  const length = quill.getSelection(true).index;
  const images = urls.split(',');
  images.map((item, index) => {
    // 插入图片
    quill.insertEmbed(length + index, 'hhImage', item);
  })
  // 调整光标到最后
  quill.setSelection(length + images.length);
}

// 插入分割线
window.insertDivider = () => {
  const length = quill.getSelection(true).index;
  quill.insertEmbed(length, 'divider', true);
  quill.setSelection(length + 1);
}

// 撤销/恢复
window.reOrUndo = (type) => {
  if (type === '1') {
    quill.history.redo();
  } else {
    quill.history.undo();
  }
}

// 插入emoji
window.insertEmoji = (unicode) => {
  const length = quill.getSelection(true).index;
  quill.insertText(length, unicode);
}

// 删除文本
window.deleteText = () => {
  const length = quill.getSelection(true).index;
  quill.deleteText(length - 1, 1);
}

// 设置平台
window.setPlatform = function (platform) {
  window.platform = platform;
}

// 设置数据
window.setData = function (title, textContent) {
  titleInput.value = title;
  quill.pasteHTML(textContent);
}

const btn = document.querySelector('.setting-btn');
const btn1 = document.querySelector('.setting-btn1');

btn.addEventListener('click', () => {
  // window.insertDivider();
  // console.log(quill.history.stack);
  // window.reOrUndo('1')
  // quill.format('bold', true)
  // quill.format('header', '1')
  // window.setData('标题标题', '<p>12313</p>')
  window.insertEmoji('\uD83D\uDE03')
})

btn1.addEventListener('click', () => {
  // quill.format('list', 'bullet')
  // const length = quill.getSelection(true).index;
  // quill.deleteText(length - 1, 1)
  // window.reOrUndo('0')
  window.insertImage('https://hhhealthapp.oss-cn-beijing.aliyuncs.com/20210114/7fd69a20-dc2d-403a-b3fc-1b73e4d0cbe11858.jpg');
})

function handleClick(evt) {
  if (evt.target && evt.target.tagName && evt.target.tagName.toUpperCase() === 'IMG') {
    if (this.img === evt.target) {
      console.log('asd');
      // we are already focused on this image
      return;
    }
    // if (this.img) {
    //   // we were just focused on another image
    //   this.hide();
    // }
    // clicked on an image inside the editor
    console.log('点击了图片', evt.target.parentNode);
    // this.show(evt.target);
    addClass(evt.target.parentNode, 'editor-image-border');
    this.img = evt.target;
  } else if (this.img) {
    // clicked on a non image
    // this.hide();
  }
}

function callWebviewMethod(name, value) {
  if (window.platform.toLowerCase() === 'ios') {
    window.webkit.messageHandlers[name].postMessage(value);
  } else {
    jktt[name](value ? value : '');
  }
}

function addClass(ele, cls) {
  if (!hasClass(ele, cls)) ele.className += ' ' + cls
}

function removeClass(ele, cls) {
  if (hasClass(ele, cls)) {
    const reg = new RegExp('(\\s|^)' + cls + '(\\s|$)')
    ele.className = ele.className.replace(reg, ' ')
  }
}

function hasClass(ele, cls) {
  return !!ele.className.match(new RegExp('(\\s|^)' + cls + '(\\s|$)'))
}
